from dig_ass_ep_protos.DigitalAssistantEntryPoint_pb2_grpc import (
    DigitalAssistantEntryPointStub,
)
from dig_ass_ep_protos.DigitalAssistantEntryPoint_pb2 import (
    DigitalAssistantEntryPointRequest,
    DigitalAssistantEntryPointResponse,
    OuterContextItem,
)

from .abstract_client import AbstractClient


class EntryPointClient(AbstractClient):
    def __init__(self, address) -> None:
        super().__init__(address)
        self._stub = DigitalAssistantEntryPointStub(self._channel)

    def __call__(
        self, text: str, outer_context: dict, image: bytearray, pdf: bytearray
    ):
        request = DigitalAssistantEntryPointRequest(
            Text=text,
            OuterContext=OuterContextItem(
                Sex=outer_context['Sex'],
                Age=outer_context['Age'],
                UserId=outer_context['UserId'],
                SessionId=outer_context['SessionId'],
                ClientId=outer_context['ClientId'],
            ),
            Image=image,
            PDF=pdf,
        )
        response: DigitalAssistantEntryPointResponse = self._stub.GetTextResponse(
            request
        )
        return response.Text



from grpc import insecure_channel
from abc import ABC, abstractmethod


class AbstractClient(ABC):
    def __init__(self, address: str) -> None:
        self._channel = insecure_channel(address)

    # https://stackoverflow.com/a/65131927
    def close(self):
        self._channel.close()

    def __enter__(self):
        return self

    def __exit__(self):
        self.close()



import io
import re
from setuptools import setup, find_packages

from dig_ass_ep_protos import __version__


def read(file_path):
    with io.open(file_path, 'r', encoding='utf-8') as f:
        return f.read()


readme = read('README.md')
# вычищаем локальные версии из файла requirements (согласно PEP440)
requirements = '\n'.join(
    re.findall(
        r'^([^\s^+]+).*$',
        read('requirements.txt'),
        flags=re.MULTILINE,
    )
)

setup(
    # metadata
    name='dig_ass_ep_protos',
    version=__version__,
    author='AGI-MED-TEAM',
    description='Proto files for dig_ass_ep_protos',
    long_description=readme,
    # options
    packages=find_packages(),
    install_requires='\n'.join([requirements]),
    include_package_data=True,
)
